@@ -1,7 +1,6 @@
 use crate::util::{format_output, Output, OutputKind};
 use nkeys::{KeyPair, KeyPairType};
 use serde_json::json;
-use std::env;
 use std::fs;
 use std::fs::File;
 use std::io::prelude::*;
@@ -43,7 +42,7 @@ pub(crate) enum KeysCliCommand {
             hide_env_values = true,
             help = "Absolute path to where keypairs are stored. Defaults to `$HOME/.wash/keys`"
         )]
-        directory: Option<String>,
+        directory: Option<PathBuf>,
         #[structopt(flatten)]
         output: Output,
     },
@@ -56,7 +55,7 @@ pub(crate) enum KeysCliCommand {
             hide_env_values = true,
             help = "Absolute path to where keypairs are stored. Defaults to `$HOME/.wash/keys`"
         )]
-        directory: Option<String>,
+        directory: Option<PathBuf>,
         #[structopt(flatten)]
         output: Output,
     },
@@ -96,12 +95,12 @@ pub(crate) fn generate(kt: &KeyPairType, output: &OutputKind) -> String {
 /// Retrieves a keypair by name in a specified directory, or $WASH_KEYS ($HOME/.wash/keys) if directory is not specified
 pub(crate) fn get(
     keyname: &str,
-    directory: Option<String>,
+    directory: Option<PathBuf>,
     output: &Output,
 ) -> Result<String, Box<dyn ::std::error::Error>> {
-    let dir = determine_directory(directory)?;
-    let mut f = File::open(format!("{}/{}", dir, keyname))
-        .map_err(|e| format!("{}.\nPlease ensure {}/{} exists.", e, dir, keyname))?;
+    let keyfile = determine_directory(directory)?.join(keyname);
+    let mut f = File::open(&keyfile)
+        .map_err(|e| format!("{}.\nPlease ensure {} exists.", e, keyfile.display()))?;
 
     let mut s = String::new();
     let res = match f.read_to_string(&mut s) {
@@ -120,14 +119,19 @@ pub(crate) fn get(
 
 /// Lists all keypairs (file extension .nk) in a specified directory or $WASH_KEYS($HOME/.wash/keys) if directory is not specified
 pub(crate) fn list(
-    directory: Option<String>,
+    directory: Option<PathBuf>,
     output: &Output,
 ) -> Result<String, Box<dyn ::std::error::Error>> {
     let dir = determine_directory(directory)?;
 
     let mut keys = vec![];
-    let paths = fs::read_dir(dir.clone())
-        .map_err(|e| format!("Error: {}, please ensure directory {} exists", e, dir))?;
+    let paths = fs::read_dir(dir.clone()).map_err(|e| {
+        format!(
+            "Error: {}, please ensure directory {} exists",
+            e,
+            dir.display()
+        )
+    })?;
 
     for path in paths {
         let f = String::from(path.unwrap().file_name().to_str().unwrap());
@@ -137,22 +141,29 @@ pub(crate) fn list(
     }
 
     Ok(format_output(
-        format!("====== Keys found in {} ======\n{}", dir, keys.join("\n")),
+        format!(
+            "====== Keys found in {} ======\n{}",
+            dir.display(),
+            keys.join("\n")
+        ),
         json!({ "keys": keys }),
         &output.kind,
     ))
 }
 
-fn determine_directory(directory: Option<String>) -> Result<String, Error> {
+fn determine_directory(directory: Option<PathBuf>) -> Result<PathBuf, Error> {
     if let Some(d) = directory {
         Ok(d)
-    } else if let Ok(home) = env::var("HOME") {
-        Ok(format!("{}/.wash/keys", home))
     } else {
-        Err(Error::new(
-            std::io::ErrorKind::NotFound,
-            "$HOME not found, please set $HOME or $WASH_KEYS for autogenerated keys".to_string(),
-        ))
+        let d = dirs::home_dir()
+            .ok_or_else(|| {
+                Error::new(
+                    std::io::ErrorKind::NotFound,
+                    "$HOME not found, please set $HOME or $WASH_KEYS for autogenerated keys",
+                )
+            })?
+            .join(".wash/keys");
+        Ok(d)
     }
 }
 
@@ -161,7 +172,7 @@ fn determine_directory(directory: Option<String>) -> Result<String, Error> {
 pub(crate) fn extract_keypair(
     input: Option<String>,
     module_path: Option<String>,
-    directory: Option<String>,
+    directory: Option<PathBuf>,
     keygen_type: KeyPairType,
     disable_keygen: bool,
 ) -> Result<KeyPair, Box<dyn std::error::Error>> {
@@ -189,12 +200,11 @@ pub(crate) fn extract_keypair(
                 .unwrap()
                 .to_string(),
         };
-        let path = format!(
-            "{}/{}_{}.nk",
-            dir,
+        let path = dir.join(format!(
+            "{}_{}.nk",
             module_name,
             keypair_type_to_string(keygen_type.clone())
-        );
+        ));
         match File::open(path.clone()) {
             // Default key found
             Ok(mut f) => {
@@ -211,7 +221,7 @@ pub(crate) fn extract_keypair(
                             "No keypair found in \"{}\".
 We will generate one for you and place it there.
 If you'd like to use alternative keys, you can supply them as a flag.\n",
-                            path
+                            path.display()
                         ),
                         json!({"status": "No keypair found", "path": path, "keygen": "true"}),
                         &Output::default().kind,
@@ -228,7 +238,7 @@ If you'd like to use alternative keys, you can supply them as a flag.\n",
             _ => {
                 return Err(format!(
                     "No keypair found in {}, please ensure key exists or supply one as a flag",
-                    path
+                    path.display()
                 )
                 .into());
             }
@@ -255,6 +265,8 @@ fn keypair_type_to_string(keypair_type: KeyPairType) -> String {
 
 #[cfg(test)]
 mod tests {
+    use std::path::PathBuf;
+
     use super::{generate, KeysCli, KeysCliCommand, OutputKind};
     use nkeys::KeyPairType;
     use serde::Deserialize;
@@ -267,12 +279,9 @@ mod tests {
         let keypair = generate(&kt, &OutputKind::Text);
         let keypair_json = generate(&kt, &OutputKind::Json);
 
-        assert_eq!(keypair.contains("Public Key: "), true);
-        assert_eq!(keypair.contains("Seed: "), true);
-        assert_eq!(
-            keypair.contains("Remember that the seed is private, treat it as a secret."),
-            true
-        );
+        assert!(keypair.contains("Public Key: "));
+        assert!(keypair.contains("Seed: "));
+        assert!(keypair.contains("Remember that the seed is private, treat it as a secret."));
         assert_ne!(keypair, "");
         assert_ne!(keypair_json, "");
     }
@@ -295,8 +304,8 @@ mod tests {
 
         assert_eq!(keypair.public_key.len(), sample_public_key.len());
         assert_eq!(keypair.seed.len(), sample_seed.len());
-        assert_eq!(keypair.public_key.starts_with('M'), true);
-        assert_eq!(keypair.seed.starts_with("SM"), true);
+        assert!(keypair.public_key.starts_with('M'));
+        assert!(keypair.seed.starts_with("SM"));
     }
 
     #[test]
@@ -319,39 +328,39 @@ mod tests {
         let cluster_keypair: KeyPairJson =
             serde_json::from_str(&generate(&KeyPairType::Cluster, &OutputKind::Json)).unwrap();
 
-        assert_eq!(account_keypair.public_key.starts_with('A'), true);
+        assert!(account_keypair.public_key.starts_with('A'));
         assert_eq!(account_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(account_keypair.seed.starts_with("SA"), true);
+        assert!(account_keypair.seed.starts_with("SA"));
         assert_eq!(account_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(user_keypair.public_key.starts_with('U'), true);
+        assert!(user_keypair.public_key.starts_with('U'));
         assert_eq!(user_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(user_keypair.seed.starts_with("SU"), true);
+        assert!(user_keypair.seed.starts_with("SU"));
         assert_eq!(user_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(module_keypair.public_key.starts_with('M'), true);
+        assert!(module_keypair.public_key.starts_with('M'));
         assert_eq!(module_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(module_keypair.seed.starts_with("SM"), true);
+        assert!(module_keypair.seed.starts_with("SM"));
         assert_eq!(module_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(service_keypair.public_key.starts_with('V'), true);
+        assert!(service_keypair.public_key.starts_with('V'));
         assert_eq!(service_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(service_keypair.seed.starts_with("SV"), true);
+        assert!(service_keypair.seed.starts_with("SV"));
         assert_eq!(service_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(server_keypair.public_key.starts_with('N'), true);
+        assert!(server_keypair.public_key.starts_with('N'));
         assert_eq!(server_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(server_keypair.seed.starts_with("SN"), true);
+        assert!(server_keypair.seed.starts_with("SN"));
         assert_eq!(server_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(operator_keypair.public_key.starts_with('O'), true);
+        assert!(operator_keypair.public_key.starts_with('O'));
         assert_eq!(operator_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(operator_keypair.seed.starts_with("SO"), true);
+        assert!(operator_keypair.seed.starts_with("SO"));
         assert_eq!(operator_keypair.seed.len(), sample_seed.len());
 
-        assert_eq!(cluster_keypair.public_key.starts_with('C'), true);
+        assert!(cluster_keypair.public_key.starts_with('C'));
         assert_eq!(cluster_keypair.public_key.len(), sample_public_key.len());
-        assert_eq!(cluster_keypair.seed.starts_with("SC"), true);
+        assert!(cluster_keypair.seed.starts_with("SC"));
         assert_eq!(cluster_keypair.seed.len(), sample_seed.len());
     }
 
@@ -434,7 +443,7 @@ mod tests {
                 output,
             } => {
                 assert_eq!(keyname, KEYNAME);
-                assert_eq!(directory, Some(KEYPATH.to_string()));
+                assert_eq!(directory, Some(PathBuf::from(KEYPATH)));
                 assert_eq!(output.kind, OutputKind::Json);
             }
             other_cmd => panic!("keys get generated other command {:?}", other_cmd),
@@ -457,7 +466,7 @@ mod tests {
         let list_all_flags = KeysCli::from_iter(&["keys", "list", "-d", KEYPATH, "-o", "json"]);
         match list_all_flags.command {
             KeysCliCommand::ListCommand { directory, output } => {
-                assert_eq!(directory, Some(KEYPATH.to_string()));
+                assert_eq!(directory, Some(PathBuf::from(KEYPATH)));
                 assert_eq!(output.kind, OutputKind::Json);
             }
             other_cmd => panic!("keys get generated other command {:?}", other_cmd),
